==> octave-2.9.18.tar.gz: octave-2.9.18/scripts/signal/detrend.m <==
## Copyright (C) 1995, 1996, 1999, 2000, 2002, 2005, 2006, 2007
##               Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.

## -*- texinfo -*-
## @deftypefn {Function File} {} detrend (@var{x}, @var{p})
## If @var{x} is a vector, @code{detrend (@var{x}, @var{p})} removes the
## best fit of a polynomial of order @var{p} from the data @var{x}.
##
## If @var{x} is a matrix, @code{detrend (@var{x}, @var{p})} does the same
## for each column in @var{x}.
##
## The second argument is optional.  If it is not specified, a value of 1
## is assumed.  This corresponds to removing a linear trend.
## @end deftypefn

## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Created: 11 October 1994
## Adapted-By: jwe

function y = detrend (x, p)

  if (nargin == 1)
    p = 1;
  elseif (nargin == 2)
    if (! (isscalar (p) && p == round (p) && p >= 0))
      error ("detrend: p must be a nonnegative integer");
    endif
  else
    print_usage ();
  endif

  [m, n] = size (x);
  if (m == 1)
    x = x';
  endif

  r = rows (x);
  b = ((1 : r)' * ones (1, p + 1)) .^ (ones (r, 1) * (0 : p));
  y = x - b * (b \ x);

  if (m == 1)
    y = y';
  endif

endfunction

==> octave3.0_3.0.0.orig.tar.gz: octave-3.0.0/scripts/signal/detrend.m <==
## Copyright (C) 1995, 1996, 1999, 2000, 2002, 2005, 2006, 2007
##               Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.

## -*- texinfo -*-
## @deftypefn {Function File} {} detrend (@var{x}, @var{p})
## If @var{x} is a vector, @code{detrend (@var{x}, @var{p})} removes the
## best fit of a polynomial of order @var{p} from the data @var{x}.
##
## If @var{x} is a matrix, @code{detrend (@var{x}, @var{p})} does the same
## for each column in @var{x}.
##
## The second argument is optional.  If it is not specified, a value of 1
## is assumed.  This corresponds to removing a linear trend.
## @end deftypefn

## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Created: 11 October 1994
## Adapted-By: jwe

function y = detrend (x, p)

  if (nargin == 1)
    p = 1;
  elseif (nargin == 2)
    if (! (isscalar (p) && p == round (p) && p >= 0))
      error ("detrend: p must be a nonnegative integer");
    endif
  else
    print_usage ();
  endif

  [m, n] = size (x);
  if (m == 1)
    x = x';
  endif

  r = rows (x);
  b = ((1 : r)' * ones (1, p + 1)) .^ (ones (r, 1) * (0 : p));
  y = x - b * (b \ x);

  if (m == 1)
    y = y';
  endif

endfunction

%!test
%! N=32;
%! x = (0:1:N-1)/N + 2;
%! y = detrend(x);
%! assert(all (all (abs (y) < 20*eps)));

%!test
%! N=32;
%! t = (0:1:N-1)/N;
%! x = t .* t + 2;
%! y = detrend(x,2);
%! assert(all (all (abs (y) < 30*eps)));

%!test
%! N=32;
%! t = (0:1:N-1)/N;
%! x = [t;4*t-3]';
%! y = detrend(x);
%! assert(all (all (abs (y) < 20*eps)));
